@@ -40,9 +40,15 @@ class NavigationWidget : public QTreeWidget {
 
     void selectItemForCursorPosition(int position);
 
+    int getNextHeadingPosition(int currentPosition) const;
+    int getPreviousHeadingPosition(int currentPosition) const;
+
    private slots:
     void onCurrentItemChanged(QTreeWidgetItem *current, QTreeWidgetItem *previous);
     void onItemClicked(QTreeWidgetItem *current, int column);
+    void onItemChanged(QTreeWidgetItem *item, int column);
+    void showContextMenu(const QPoint &pos);
+    void renameHeadingTriggered();
 
    private:
     void buildNavTree(const QVector<Node> &nodes);
@@ -50,6 +56,7 @@ class NavigationWidget : public QTreeWidget {
 
    signals:
     void positionClicked(int position);
+    void headingRenamed(int position, const QString &oldText, const QString &newText);
 
    private:
     const QTextDocument *_doc;
